@@ -56,11 +56,12 @@ class select_geoms:
                 if data.crs == None:
                     data.crs = {'init': 'epsg:3857'}
                 check_topology(data)
-            except TypeError:
-                datad = gpd.read_file(self.gdf_path).to_crs({'init': 'epsg:3857'})
+            except ValueError:
+                datad = gpd.read_file([i for i in glob.glob(f"{self.gdf_path}/*.shp")]).to_crs({'init': 'epsg:3857'})
                 data = datad.copy().to_crs({'init': 'epsg:3857'})
                 if data.crs == None:
                     data.crs = {'init': 'epsg:3857'}
+                print(f"\nCRS is {data.crs} for {self.gdf_path}")
                 data = data.explode().reset_index().drop(['level_0', 'level_1'], axis = 1)
                 check_topology(data)
         else:
